@@ -50,6 +50,12 @@ void FrameBuffer::getServerFormat(rfbPixelFormat &)
 {
 }
 
+QVariant FrameBuffer::customProperty(const QString &property) const
+{
+    Q_UNUSED(property)
+    return QVariant();
+}
+
 int FrameBuffer::depth()
 {
     return 32;
